@@ -25,10 +25,12 @@ Mojolicious::Plugin::Minion - Minion job queue plugin
 =head1 SYNOPSIS
 
   # Mojolicious (choose a backend)
-  $self->plugin(Minion => {File  => '/Users/sri/minion.db'});
+  $self->plugin(Minion => {File => '/Users/sri/minion.db'});
+  $self->plugin(Minion => {Pg   => 'postgresql://postgres@/test'});
 
   # Mojolicious::Lite (choose a backend)
-  plugin Minion => {File  => '/Users/sri/minion.db'};
+  plugin Minion => {File => '/Users/sri/minion.db'};
+  plugin Minion => {Pg   => 'postgresql://postgres@/test'};
 
   # Add tasks to your application
   app->minion->add_task(slow_log => sub {
